aboutsummaryrefslogtreecommitdiff
path: root/src/pkg/syscall/syscall_linux.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/pkg/syscall/syscall_linux.go')
-rw-r--r--src/pkg/syscall/syscall_linux.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/pkg/syscall/syscall_linux.go b/src/pkg/syscall/syscall_linux.go
index 50d6fa9837..e4a6561ce5 100644
--- a/src/pkg/syscall/syscall_linux.go
+++ b/src/pkg/syscall/syscall_linux.go
@@ -784,8 +784,8 @@ func ParseDirent(buf []byte, max int, names []string) (consumed int, count int,
return origlen - len(buf), count, names
}
-//sys mount(source string, target string, fstype string, flags uint32, data *byte) (errno int)
-func Mount(source string, target string, fstype string, flags uint32, data string) (errno int) {
+//sys mount(source string, target string, fstype string, flags uintptr, data *byte) (errno int)
+func Mount(source string, target string, fstype string, flags uintptr, data string) (errno int) {
// Certain file systems get rather angry and EINVAL if you give
// them an empty string of data, rather than NULL.
if data == "" {